@@ -1,3 +1,7 @@
+from marta.models.arrival import (
+    Arrival,
+    Arrivals,
+)
 from marta.models.bus import (
     Bus,
     LegacyBus,
@@ -6,7 +10,6 @@ from marta.models.bus import (
 )
 from marta.models.train import (
     Train,
-    LegacyTrain,
     RealTimeTrain,
     RealTimeMapTrain,
     RealTimeMapTrainPrediction,
